@@ -28,12 +28,13 @@ our parent L<PPI::Token> and L<PPI::Element> classes.
 =cut
 
 use strict;
-use base 'PPI::Token';
 use IO::String ();
+use PPI::Token ();
 
-use vars qw{$VERSION};
+use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '1.201';
+	$VERSION = '1.236';
+	@ISA     = 'PPI::Token';
 }
 
 
@@ -64,7 +65,19 @@ sub handle {
 	IO::String->new( \$self->{content} );
 }
 
-sub __TOKENIZER__on_char { 1 }
+sub __TOKENIZER__on_line_start {
+	my ( $self, $t ) = @_;
+
+	# Add the line
+	if ( defined $t->{token} ) {
+		$t->{token}->{content} .= $t->{line};
+	}
+	else {
+		defined( $t->{token} = $t->{class}->new( $t->{line} ) ) or return undef;
+	}
+
+	return 0;
+}
 
 1;
 
@@ -80,7 +93,7 @@ Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2006 Adam Kennedy.
+Copyright 2001 - 2011 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
